from ngsolve import *
import numpy as np
import netgen.gui


mesh = Mesh("/Users/wintersperger/Desktop/ngsovle_simple/cube_simple.vol")
names = [ "bottom", "top", "left", "right", "front", "back", "inner" ]
for i, name in enumerate(names):
    mesh.ngmesh.SetBCName(i, name)

B0 = 1

V = HCurl(mesh, order = 1, dirichlet = "right|back|bottom|front")
u = V.TrialFunction()
v = V.TestFunction()
uh = GridFunction(V)

dirvalues = { "right" : (0,25e-3*B0*x,0), "back" : (-25e-3*B0*y,0,0)}

dirlist = [ dirvalues[bcname] if bcname in dirvalues.keys() else (0,0,0) \
                for bcname in mesh.GetBoundaries() ]
coeff_dirichlet = CoefficientFunction( dirlist )
uh.Set(coeff_dirichlet, BND)

a = BilinearForm(V, symmetric=True)
a += SymbolicBFI(InnerProduct(curl(u), curl(v)))
f = LinearForm(V)
c = Preconditioner(a, "direct")

with TaskManager():
    a.Assemble()
    f.Assemble()
    bvp = BVP(bf=a, lf=f, gf=uh, pre=c)
    bvp.Do()

Draw(uh, mesh, "A")
Draw(curl(uh), mesh, "B")
